#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['sp_calculator']

package_data = \
{'': ['*'],
 'sp_calculator': ['.pytest_cache/*',
                   '.pytest_cache/v/*',
                   '.pytest_cache/v/cache/*']}

setup(name='sp_calculator',
      version='0.2.1',
      description='A basic dependency-free calculator module',
      author=None,
      author_email='Seb <sebastianpikand@gmail.com>',
      url=None,
      packages=packages,
      package_data=package_data,
     )
